import { ChangeEventHandler } from "react"

interface CheckboxProps {
  checked: boolean
  label: string
  onChange: ChangeEventHandler<HTMLInputElement>
  id: string
}

export default function Checkbox({
  checked,
  label,
  onChange,
  id,
}: CheckboxProps) {
  return (
    <div className="mb-2 block text-xs font-bold text-gray-700">
      <label htmlFor={id} className="flex cursor-pointer items-center">
        <div className="relative">
          <input
            id={id}
            type="checkbox"
            className="sr-only"
            checked={checked}
            onChange={onChange}
          />
          <div className="block h-6 w-6 rounded-md border-2 border-gray-300 bg-white ">
            <div
              className={`${
                checked ? "opacity-100" : "opacity-0"
              } absolute inset-0 flex h-full w-full items-center justify-center`}
            >
              <svg
                className="h-4 w-4 text-blue-600"
                fill="none"
                strokeLinecap="round"
                strokeLinejoin="round"
                strokeWidth="2"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path d="M5 13l4 4L19 7"></path>
              </svg>
            </div>
          </div>
        </div>
        <span className="ml-2">{label}</span>
      </label>
    </div>
  )
}
