import { useQuery } from "@tanstack/react-query"
import ErrorBlock from "./error"
import Loader from "./loader"

interface WithDataFetchingProps<T> {
  queryKey: string[]
  queryFn: () => Promise<T>
  refetchInterval?: number
  refetchOnWindowFocus?: boolean
  enabled?: boolean
  children: (data: T) => React.ReactNode
}

export default function WithDataFetching<T>({
  queryKey,
  queryFn,
  refetchInterval,
  refetchOnWindowFocus,
  enabled,
  children,
}: WithDataFetchingProps<T>) {
  const { data, isLoading, isError, error } = useQuery<T, Error>({
    queryKey: queryKey,
    queryFn: queryFn,
    refetchInterval: refetchInterval,
    refetchOnWindowFocus: refetchOnWindowFocus,
    enabled: enabled,
  })

  if (isLoading) return <Loader />
  if (isError) return <ErrorBlock error={error} />
  if (!data) return ErrorBlock({ error: new Error("Data not found") })

  return <>{children(data)}</>
}
