import { Link, useLocation } from "react-router-dom"
import { SearchBox } from "../components/searchBox"

interface HeaderLinkButtonProps {
  to: string
  label: string
}

const HeaderLinkButton = ({ to, label }: HeaderLinkButtonProps) => {
  const location = useLocation()
  const isActive = location.pathname === to
  return (
    <Link
      to={to}
      className={`w-36 rounded-lg px-4 py-2 text-white hover:bg-primary-600 hover:shadow-lg ${isActive ? "bg-primary-700" : "bg-primary-500"}`}
    >
      <span className="font-secondary text-lg font-semibold">{label}</span>
    </Link>
  )
}

export default function Header() {
  return (
    <div className="relative z-50 grid grid-cols-[auto_1fr] items-center gap-3 border-b border-neutral-300 bg-primary-200 p-3 shadow-md ">
      <div className="w-96">
        <SearchBox />
      </div>
      <div className="flex items-center justify-end gap-3 ">
        <HeaderLinkButton to="/" label="Rankings" />
        <HeaderLinkButton to="/live" label="Live" />
        <HeaderLinkButton to="/xpcenter" label="XP Center" />
      </div>
    </div>
  )
}
