import { useMemo } from "react"
import { Link, useParams } from "react-router-dom"
import { GetPlayer } from "../../api/player"
import WithDataFetching from "../../components/withdatafetching"
import Player from "../../types/player"

export default function ClubHistory() {
  const { slug } = useParams()
  if (!slug) {
    return <div>No</div>
  }
  return (
    <WithDataFetching
      queryKey={["player", slug]}
      queryFn={() => GetPlayer(slug)}
    >
      {(player: Player) => <ClubHistoryLayout player={player} />}
    </WithDataFetching>
  )
}

function ClubHistoryLayout({ player }: { player: Player }) {
  const clubMemberships = useMemo(
    () =>
      player.clubMembership
        .filter((membership) => membership.membershipType === "club")
        .sort((a, b) => {
          if (!a.endDate && !b.endDate) {
            return (
              new Date(b.startDate).getTime() - new Date(a.startDate).getTime()
            )
          }
          if (!a.endDate) return -1
          if (!b.endDate) return 1
          if (new Date(a.endDate).getTime() === new Date(b.endDate).getTime()) {
            return (
              new Date(b.startDate).getTime() - new Date(a.startDate).getTime()
            )
          }
          return new Date(b.endDate).getTime() - new Date(a.endDate).getTime()
        }),
    [player.clubMembership]
  )
  return (
    <div className="grid grid-cols-[auto_auto_3fr_1fr_1fr] items-center gap-3">
      {clubMemberships.map((membership) => (
        <>
          <div className="flex justify-center border shadow-md">
            <img
              className="w-6"
              src={membership.team?.country?.flagFlat32Url}
              title={membership.team?.domesticLeague?.displayName}
            />
          </div>
          <Link to={`/team/${membership.team?.slug}`}>
            <div className="flex justify-center">
              <img className="h-10" src={membership.team?.pictureUrl} />
            </div>
          </Link>

          <div>{membership.team?.displayName}</div>
          <div className="flex items-baseline gap-1">
            <span>
              {new Date(membership.startDate).toLocaleDateString(undefined, {
                month: "numeric",
                year: "numeric",
              })}
            </span>
            <span>{membership.endDate ? "->" : ""}</span>
            <span>
              {membership.endDate
                ? new Date(membership.endDate).toLocaleDateString(undefined, {
                    month: "numeric",
                    year: "numeric",
                  })
                : ""}
            </span>
          </div>
          <div>
            {(() => {
              const endDate = membership.endDate
                ? new Date(membership.endDate)
                : new Date()
              const startDate = new Date(membership.startDate)
              const diffDays = Math.floor(
                (endDate.getTime() - startDate.getTime()) /
                  (1000 * 60 * 60 * 24)
              )
              const diffYears = Math.floor(diffDays / 365)
              const remainingDays = diffDays % 365
              if (diffYears > 1) {
                return `${diffYears} years ${remainingDays} days`
              } else if (diffYears === 1) {
                return `1 year ${remainingDays} days`
              } else {
                return `${diffDays} days`
              }
            })()}
          </div>
        </>
      ))}
    </div>
  )
}
