import { useState } from "react"

function extractDateWithOffset(date: Date, offsetDays: number) {
  const year = date.getFullYear()
  const month = date.getMonth()
  const day = date.getDate()

  const resultDate = new Date(year, month, day)
  resultDate.setDate(resultDate.getDate() + offsetDays)

  return resultDate
}

const CustomRadioButton = ({
  value,
  currentValue,
  onClick,
  label,
}: {
  value: string
  currentValue: string
  onClick: (value: string) => void
  label: string
}) => {
  const isActive = value === currentValue
  const bg = isActive ? "bg-primary-blue-500" : "bg-neutral-700"
  const hoverBg = isActive
    ? "hover:bg-primary-blue-600"
    : "hover:bg-neutral-600"
  const activeBg = isActive
    ? "active:bg-primary-blue-700"
    : "active:bg-neutral-500"

  return (
    <button
      aria-label={label}
      onClick={() => onClick(value)}
      className={`btn py-1 text-white ${bg} ${hoverBg} ${activeBg}`}
    >
      {label}
    </button>
  )
}

function DaysSelector({
  days,
  setDays,
}: {
  days: number
  setDays: (days: number) => void
}) {
  return (
    <div className="flex space-x-3">
      <CustomRadioButton
        value={"3"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="3 days"
      />
      <CustomRadioButton
        value={"7"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="1 week"
      />
      <CustomRadioButton
        value={"30"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="1 month"
      />
      <CustomRadioButton
        value={"90"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="3 months"
      />
      <CustomRadioButton
        value={"180"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="6 months"
      />
      <CustomRadioButton
        value={"365"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="1 year"
      />
      <CustomRadioButton
        value={"0"}
        currentValue={String(days)}
        onClick={(value) => setDays(Number(value))}
        label="All"
      />
    </div>
  )
}

export default function DaysSelectionWrapper({
  children,
}: {
  children: (startDate: Date, endDate: Date) => React.ReactNode
}) {
  const [days, setDays] = useState(365)
  const farEnoughDate = new Date(2000, 0, 1) // You can set this to an earlier date if needed
  const startDate =
    days === 0 ? farEnoughDate : extractDateWithOffset(new Date(), -days)
  const endDate = extractDateWithOffset(new Date(), 1)

  return (
    <div className="flex flex-col items-center gap-12">
      <DaysSelector days={days} setDays={setDays} />
      <div className="w-full">{children(startDate, endDate)}</div>
    </div>
  )
}
