import Select, { MultiValue, SingleValue } from "react-select"

interface FilterOption<T> {
  value: T
  label: string
}

interface FilterSelectProps<T> {
  value: T
  options: FilterOption<T>[]
  onChange: (value: T) => void
  isSearchable?: boolean
}

export function FilterSelect<T>({
  value,
  options,
  onChange,
  isSearchable = false,
}: FilterSelectProps<T>) {
  return (
    <Select
      value={options.find((option: FilterOption<T>) => option.value === value)}
      isSearchable={isSearchable}
      options={options}
      onChange={(option: SingleValue<FilterOption<T>>) => {
        if (option) {
          onChange(option.value)
        }
      }}
    />
  )
}

interface FilterSelectMultiProps<T> {
  values: T[]
  options: FilterOption<T>[]
  onChange: (value: T[]) => void
  isSearchable?: boolean
  placeHolder?: string
}

export function FilterSelectMulti<T>({
  values,
  options,
  onChange,
  isSearchable = false,
  placeHolder = "Select",
}: FilterSelectMultiProps<T>) {
  return (
    <Select
      value={options.filter((option: FilterOption<T>) =>
        values.includes(option.value)
      )}
      isMulti
      isSearchable={isSearchable}
      options={options}
      placeholder={placeHolder}
      isDisabled={options.length === 0}
      onChange={(options: MultiValue<FilterOption<T>>) => {
        onChange(options.map((option: FilterOption<T>) => option.value) as T[])
      }}
    />
  )
}
