import { useParams } from "react-router"
import { GetPlayer, GetPlayerGames } from "../../api/player"
import WithDataFetching from "../../components/withdatafetching"
import Player from "../../types/player"
import DaysSelectionWrapper from "./components/days_selection"
import ScoreGraph from "./score_graph"
import ScoreTable from "./score_table"

export default function Scores() {
  const { slug } = useParams()
  if (!slug) {
    return <div>No</div>
  }
  return (
    <WithDataFetching
      queryKey={["player", slug]}
      queryFn={() => GetPlayer(slug)}
    >
      {(player: Player) => (
        <DaysSelectionWrapper>
          {(startDate, endDate) => {
            return (
              <WithDataFetching
                queryKey={["playerScores", player.slug]}
                queryFn={() => GetPlayerGames(player.slug)}
                refetchOnWindowFocus={false}
              >
                {(scores) => {
                  return (
                    <div className="flex flex-col items-center gap-12">
                      <ScoreGraph
                        scores={scores}
                        startDate={startDate}
                        endDate={endDate}
                      />
                      <ScoreTable player={player} scores={scores} />
                    </div>
                  )
                }}
              </WithDataFetching>
            )
          }}
        </DaysSelectionWrapper>
      )}
    </WithDataFetching>
  )
}
