import { Link } from "react-router-dom"
import Player from "../../types/player"

function Badge({
  imgUrl,
  name,
  imgHeight = "full",
}: {
  imgUrl?: string
  name?: string
  imgHeight?: string
}) {
  return (
    <div className="flex h-8 items-center gap-3 rounded-full border border-neutral-300 bg-gradient-to-r from-primary-blue-200 to-neutral-50 px-3 py-1 shadow-md">
      <img src={imgUrl} className={`h-${imgHeight}`} />
      <span className="text-sm">{name}</span>
    </div>
  )
}

export default function Sidebar({ player }: { player: Player }) {
  return (
    <div className="flex flex-col items-center gap-3 border-r border-r-neutral-300 bg-gradient-to-b from-neutral-100 to-neutral-50 p-3 text-neutral-700  shadow-md">
      <div className="flex h-32 w-32 items-center justify-center overflow-hidden rounded-full border bg-neutral-50 p-3">
        <img
          src={player.avatarUrl}
          className="h-full w-full scale-[1.16] object-contain"
        />
      </div>

      <span className="font-secondary text-lg font-semibold">
        {player.displayName}
      </span>
      <div className="flex flex-col items-center justify-center gap-0.5">
        <span className="text-sm">
          {new Date().getFullYear() - new Date(player.birthDate).getFullYear()}
        </span>
        <span className="text-xs">
          {new Date(player.birthDate).toLocaleDateString("en-GB", {
            year: "numeric",
            month: "2-digit",
            day: "2-digit",
          })}
        </span>
      </div>
      <Badge
        imgUrl={player.country?.flagFlat64Url}
        name={player.country?.displayName}
        imgHeight="4"
      />
      <Link to={`/team/${player.team?.slug}`}>
        <Badge imgUrl={player.team?.pictureUrl} name={player.team?.shortName} />
      </Link>
      <Badge
        imgUrl={player.domesticLeague?.pictureUrl}
        name={player.domesticLeague?.displayName}
      />
    </div>
  )
}
