import { useQuery } from "@tanstack/react-query";
import { SingleRankingsParams } from "../../api/rankings";
import { GetAllZones } from "../../api/zone";
import Zone from "../../types/zone";

interface ZoneSelectProps {
  params: SingleRankingsParams;
  setParams: (params: SingleRankingsParams) => void;
}

export default function ZoneSelect({ params, setParams }: ZoneSelectProps) {
  const { data: zones } = useQuery({
    queryKey: ["zones"],
    queryFn: async () => {
      const zones = await GetAllZones();
      return zones.sort((a, b) => a.displayName.localeCompare(b.displayName));
    },
  });

  const handleZoneChange = (zone: Zone) => {
    const newZones = params.zones.includes(zone.id)
      ? params.zones.filter((z) => z !== zone.id)
      : [...params.zones, zone.id];
    setParams({
      ...params,
      zones: newZones,
    });
  };

  return (
    <div className="flex border-2 border-gray-300 rounded-xl overflow-hidden">
      {zones?.map((zone, index) => (
        <div
          key={zone.id}
          className={`flex-auto ${index > 0 ? "border-l-2 border-gray-300" : ""}`}
        >
          <button
            className={`w-full py-1 px-3 ${
              params.zones.includes(zone.id)
                ? "bg-primary-blue-500 hover:bg-primary-blue-700 text-white"
                : "bg-white hover:bg-neutral-100 text-neutral-800"
            }`}
            onClick={() => handleZoneChange(zone)}
          >
            {zone.displayName}
          </button>
        </div>
      ))}
    </div>
  );
}
