import { createBrowserRouter, Link, RouterProvider } from "react-router-dom"
import Layout from "../pages/layout"
import Live from "../pages/live"
import { playerRoutes } from "../pages/player/routes"
import SingleRankingsPage from "../pages/singlerankings"
import { teamRoutes } from "../pages/team/routes"
import XpCenter from "../pages/xpcenter"

const router = createBrowserRouter([
  {
    path: "/",
    element: <Layout />,
    children: [
      { path: "", element: <SingleRankingsPage /> },
      { path: "live", element: <Live /> },
      { path: "xpcenter", element: <XpCenter /> },
      { path: "xpcenter/:slug", element: <XpCenter /> },
      playerRoutes,
      teamRoutes,
    ],
  },
  {
    path: "*",
    element: <NoMatch />,
  },
])

export default function RouterOutlet() {
  return <RouterProvider router={router} />
}

function NoMatch() {
  return (
    <div className="flex h-screen w-full flex-col items-center justify-center text-center">
      <div className="rounded-xl bg-white p-4 shadow-xl dark:bg-gray-700">
        <h1 className="mb-4 text-4xl text-gray-800 md:text-6xl dark:text-gray-200">
          404
        </h1>
        <h2 className="mb-8 text-2xl text-gray-800 md:text-4xl dark:text-gray-200">
          Page Not Found
        </h2>
        <p className="text-md mb-8 text-gray-800 md:text-lg dark:text-gray-200">
          The page you are looking for doesn&apos;t exist or has been moved.
        </p>
        <Link to="/">
          <div className="inline-block">
            <button className="btn bg-primary-blue-500 hover:bg-primary-blue-700">
              Go Home
            </button>
          </div>
        </Link>
      </div>
    </div>
  )
}
