import Competition from "./competition"
import { Fixture } from "./fixture"
import Player from "./player"
import Team from "./team"

export interface Game {
  id: string
  date: Date
  coverageStatus: string
  lowCoverage: boolean
  minutes: number
  periodType: string
  scored: boolean
  status: string
  competitionSlug: string
  fixtureSlug: string
  awayTeamSlug: string
  awayGoals: number
  awayExtraTimeScore: number
  awayPenaltyScore: number
  homeTeamSlug: string
  homeGoals: number
  homeExtraTimeScore: number
  homePenaltyScore: number
  winnerTeamSlug: string
  competition: Competition
  homeTeam: Team
  awayTeam: Team
  winnerTeam: Team
  gamePlayers: GamePlayer[]
  fixture: Fixture
}

export interface GamePlayer {
  gameId: string
  playerSlug: string
  teamSlug: string
  status: string

  game?: Game
  player?: Player
  score?: GamePlayerScore
}

export interface GamePlayerScore {
  gameId: string
  playerSlug: string
  gameDate: Date
  score: number
  decisiveScore: number
  allAroundScore: number
  minutesPlayed: number
  gameStarted: boolean
  formationPlace: number
  live: boolean
  onGameSheet: boolean
  reviewed: boolean
  goal: number
  assist: number
  penaltyWon: number
  clearanceOffLine: number
  lastManTackle: number
  penaltySave: number
  ownGoal: number
  redCard: boolean
  errorLeadToGoal: number
  penaltyConceded: number
  yellowCard: number
  fouls: number
  fouled: number
  cleanSheet: boolean
  doubleDouble: boolean
  tripleDouble: boolean
  tripleTriple: boolean
  errorLeadToShot: number
  saves: number
  savedShotFromInsideBox: number
  goodHighClaim: number
  punches: number
  divingSave: number
  divingCatch: number
  crossNotClaimed: number
  goalkeeperSmother: number
  sixSecondViolation: number
  keeperSweeper: number
  goalsConceded: number
  effectiveClearance: number
  wonTackle: number
  blockedCross: number
  block: number
  possessionLost: number
  possessionWon: number
  duelLost: number
  duelWon: number
  interception: number
  accuratePass: number
  accurateFinalThirdPass: number
  accurateLongBall: number
  longPassIntoOpposition: number
  missedPass: number
  shotOnTarget: number
  wonContest: number
  bigChanceCreated: number
  attemptedAssist: number
  penaltyAreaEntries: number
  penaltyKickMissed: number
  bigChanceMissed: number
}

export function GetScoreColor(score: number, tailwind: boolean): string {
  if (score < 15) {
    return tailwind ? "bg-support-red-400" : "#FF0000" // red
  } else if (score < 40) {
    return tailwind ? "bg-orange-400" : "#FFA500" // orange
  } else if (score < 60) {
    return tailwind ? "bg-yellow-400" : "#FFFF00" // yellow
  } else if (score < 75) {
    return tailwind ? "bg-green-600" : "#32CD32" // lime green, a bit darker than light green
  } else {
    return tailwind ? "bg-green-700" : "#006400" // dark green
  }
}

export function GetLScoreColor(score: number): string {
  if (score < 40) {
    return "bg-support-red-500"
  } else if (score < 46) {
    return "bg-orange-500"
  } else if (score < 54) {
    return "bg-yellow-500"
  } else if (score < 66) {
    return "bg-green-500"
  } else {
    return "bg-green-600"
  }
}

export function GetDSScoreColor(score: number): string {
  if (score < 34) {
    return "bg-support-red-500"
  } else if (score < 37) {
    return "bg-orange-500"
  } else if (score < 42) {
    return "bg-yellow-500"
  } else if (score < 52) {
    return "bg-green-500"
  } else {
    return "bg-green-600"
  }
}

export function GetAAScoreColor(score: number): string {
  if (score < 7) {
    return "bg-support-red-500"
  } else if (score < 10) {
    return "bg-orange-500"
  } else if (score < 16) {
    return "bg-yellow-500"
  } else if (score < 25) {
    return "bg-green-500"
  } else {
    return "bg-green-600"
  }
}

export function GetMinutesScoreColor(score: number): string {
  if (score < 38) {
    return "bg-support-red-500"
  } else if (score < 58) {
    return "bg-orange-500"
  } else if (score < 78) {
    return "bg-yellow-500"
  } else if (score < 90) {
    return "bg-green-500"
  } else {
    return "bg-green-600"
  }
}
